@@ -3,18 +3,19 @@
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 import os
+import pathlib
 import warnings
 from functools import lru_cache
 from urllib.parse import urlparse
 
+from jupyter_server.base.handlers import FileFindHandler, JupyterHandler
 from jupyter_server.extension.handler import ExtensionHandlerJinjaMixin, ExtensionHandlerMixin
+from jupyter_server.utils import url_path_join as ujoin
 from tornado import template, web
 
 from .config import LabConfig, get_page_config, recursive_update
 from .licenses_handler import LicensesHandler, LicensesManager
 from .listings_handler import ListingsHandler, fetch_listings
-from .server import FileFindHandler, JupyterHandler
-from .server import url_path_join as ujoin
 from .settings_handler import SettingsHandler
 from .themes_handler import ThemesHandler
 from .translations_handler import TranslationsHandler
@@ -84,16 +85,23 @@ class LabHandler(ExtensionHandlerJinjaMixin, ExtensionHandlerMixin, JupyterHandl
         page_config["store_id"] = self.application.store_id  # type:ignore
 
         server_root = os.path.normpath(os.path.expanduser(server_root))
+        preferred_path = ""
         try:
-            # Remove the server_root from pref dir
-            if self.serverapp.preferred_dir != server_root:
-                page_config["preferredPath"] = "/" + os.path.relpath(
-                    self.serverapp.preferred_dir, server_root
-                )
-            else:
-                page_config["preferredPath"] = "/"
+            preferred_path = self.serverapp.contents_manager.preferred_dir
         except Exception:
-            page_config["preferredPath"] = "/"
+            # FIXME: Remove fallback once CM.preferred_dir is ubiquitous.
+            try:
+                # Remove the server_root from app pref dir
+                if self.serverapp.preferred_dir and self.serverapp.preferred_dir != server_root:
+                    preferred_path = (
+                        pathlib.Path(self.serverapp.preferred_dir)
+                        .relative_to(server_root)
+                        .as_posix()
+                    )
+            except Exception:
+                pass  # noqa  # we do not require the preferred_dir trait to be present
+        # JupyterLab relies on an unset/default path being "/"
+        page_config["preferredPath"] = preferred_path or "/"
 
         self.application.store_id += 1  # type:ignore
 
@@ -167,7 +175,7 @@ class NotFoundHandler(LabHandler):
         return page_config
 
 
-def add_handlers(handlers, extension_app):
+def add_handlers(handlers, extension_app):  # noqa
     """Add the appropriate handlers to the web app."""
     # Normalize directories.
     for name in LabConfig.class_trait_names():
@@ -238,7 +246,6 @@ def add_handlers(handlers, extension_app):
 
     # Handle saved workspaces.
     if extension_app.workspaces_dir:
-
         workspaces_config = {"manager": WorkspacesManager(extension_app.workspaces_dir)}
 
         # Handle requests for the list of workspaces. Make slash optional.
@@ -263,7 +270,7 @@ def add_handlers(handlers, extension_app):
 
         sys.exit(-1)
 
-    ListingsHandler.listings_refresh_seconds = settings_config.get(  # type:ignore
+    ListingsHandler.listings_refresh_seconds = settings_config.get(
         "listings_refresh_seconds", 60 * 60
     )
     ListingsHandler.listings_request_opts = settings_config.get("listings_request_options", {})
@@ -283,10 +290,10 @@ def add_handlers(handlers, extension_app):
     ):
         from tornado import ioloop
 
-        callback_time = (ListingsHandler.listings_refresh_seconds * 1000,)  # type:ignore
+        callback_time = ListingsHandler.listings_refresh_seconds * 1000
         ListingsHandler.pc = ioloop.PeriodicCallback(
             lambda: fetch_listings(None),  # type:ignore
-            callback_time=callback_time,  # type:ignore
+            callback_time=callback_time,
             jitter=0.1,
         )
         ListingsHandler.pc.start()  # type:ignore
