@@ -1,3 +1,6 @@
+# Copyright (c) Jupyter Development Team.
+# Distributed under the terms of the Modified BSD License.
+
 """A workspace management CLI"""
 import json
 import sys
@@ -172,7 +175,8 @@ class WorkspaceImportApp(JupyterApp, LabConfig):
         workspace = json.load(data)
 
         if "data" not in workspace:
-            raise Exception("The `data` field is missing.")
+            msg = "The `data` field is missing."
+            raise Exception(msg)
 
         # If workspace_name is set in config, inject the
         # name into the workspace metadata.
@@ -180,6 +184,7 @@ class WorkspaceImportApp(JupyterApp, LabConfig):
             workspace["metadata"] = {"id": self.workspace_name}
         else:
             if "id" not in workspace["metadata"]:
-                raise Exception("The `id` field is missing in `metadata`.")
+                msg = "The `id` field is missing in `metadata`."
+                raise Exception(msg)
 
         return workspace
